package cn.com.countrygarden.bi.main.dao.reportCityData;

import cn.com.countrygarden.bi.main.dto.reportCityData.CcdrDto;
import cn.com.countrygarden.bi.main.dto.reportCityData.CclDto;
import cn.com.countrygarden.bi.main.dto.reportCityData.CcsjDto;
import cn.com.countrygarden.bi.main.dto.reportCityData.CcsrDto;
import cn.com.countrygarden.bi.main.dto.reportCityData.CcufDto;
import com.github.pagehelper.PageRowBounds;

import java.util.List;

public interface CityCompanyDataMapper {


    CcdrDto queryData(Integer ccdrId);

    List<CcdrDto> queryUnionData(CcdrDto ccdrDto, PageRowBounds pageRowBounds);
    List<CcdrDto> queryUnionData(CcdrDto ccdrDto);

    int updateData(CcdrDto ccdrDto);

    int addData(CcdrDto ccdrDto);

    int addCclData(CcdrDto ccdrDto);

    int addCcsjData(CcdrDto ccdrDto);

    int addCcsjDto(CcsjDto ccsjDto);

    int addCcsrData(CcdrDto ccdrDto);

    int addCcsrDto(CcsrDto ccsrDto);

    int addCcufData(CcdrDto ccdrDto);

    int updateCclDto(CcdrDto ccdrDto);

    int updateCcsjDto(CcdrDto ccdrDto);

    int updateCcsrDto(CcdrDto ccdrDto);

    int updateCcufDto(CcdrDto ccdrDto);

    int deleteCclData(Integer ccdrId);

    int deleteCcsjData(Integer ccdrId);

    int deleteCcsrData(Integer ccdrId);

    int deleteCcufData(Integer ccdrId);

    int deleteData(Integer ccdrId);

    int deleteCcsj(Long ccsjId);

    int deleteCcsr(Long ccsrId);

    int deleteCcl(Long cclId);

    int addCcufDto(CcufDto ccuf);

    int addCclDto(CclDto cclDto);

    int deleteCcuf(Long fileId);

    CcufDto getCcufDtoListById(Long id);
}
